package betterquesting.questing.rewards;

import betterquesting.api.placeholders.rewards.FactoryRewardPlaceholder;
import betterquesting.api.questing.rewards.IReward;
import betterquesting.api2.registry.IFactoryData;
import betterquesting.api2.registry.IRegistry;
import betterquesting.core.BetterQuesting;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.util.ResourceLocation;
import org.apache.logging.log4j.Level;

/* loaded from: betterquesting_questing_rewards.jar:betterquesting/questing/rewards/RewardRegistry.class */
public class RewardRegistry implements IRegistry<IFactoryData<IReward, NBTTagCompound>, IReward> {
    public static final RewardRegistry INSTANCE = new RewardRegistry();
    private final HashMap<ResourceLocation, IFactoryData<IReward, NBTTagCompound>> rewardRegistry = new HashMap<>();

    public void register(IFactoryData<IReward, NBTTagCompound> factory) {
        if (factory == null) {
            throw new NullPointerException("Tried to register null reward");
        }
        if (factory.getRegistryName() == null) {
            throw new IllegalArgumentException("Tried to register a reward with a null name: " + factory.getClass());
        }
        if (this.rewardRegistry.containsKey(factory.getRegistryName()) || this.rewardRegistry.containsValue(factory)) {
            throw new IllegalArgumentException("Cannot register dupliate reward type: " + factory.getRegistryName());
        }
        this.rewardRegistry.put(factory.getRegistryName(), factory);
    }

    /* renamed from: getFactory, reason: merged with bridge method [inline-methods] */
    public IFactoryData<IReward, NBTTagCompound> m2getFactory(ResourceLocation registryName) {
        return this.rewardRegistry.get(registryName);
    }

    public List<IFactoryData<IReward, NBTTagCompound>> getAll() {
        return new ArrayList(this.rewardRegistry.values());
    }

    /* renamed from: createNew, reason: merged with bridge method [inline-methods] */
    public IReward m1createNew(ResourceLocation registryName) {
        FactoryRewardPlaceholder m2getFactory;
        try {
            if (FactoryRewardPlaceholder.INSTANCE.getRegistryName().equals(registryName)) {
                m2getFactory = FactoryRewardPlaceholder.INSTANCE;
            } else {
                m2getFactory = m2getFactory(registryName);
            }
            if (m2getFactory == null) {
                BetterQuesting.logger.log(Level.ERROR, "Tried to load missing reward type '" + registryName + "'! Are you missing an expansion pack?");
                return null;
            }
            return (IReward) m2getFactory.createNew();
        } catch (Exception e) {
            BetterQuesting.logger.log(Level.ERROR, "Unable to instatiate reward: " + registryName, e);
            return null;
        }
    }
}
